@@ -122,6 +122,9 @@
 /* Define as 1 if you have gettext and don't want to use GNU gettext.  */
 #undef HAVE_GETTEXT
 
+/* Define as 1 if you have Heimdal Kerberos */
+#undef HAVE_HEIMDAL
+
 /* Define if you have innetgr() defined in include file */
 #undef HAVE_INNETGR_DEF
 
@@ -412,6 +415,12 @@
    instead of <sys/cpustats.h>.  */
 #undef UMAX4_3
 
+/* Define if you want a UNIX socket used */
+#undef UNIXSOCKET
+
+/* Location of the UNIX socket */
+#undef UNIXSOCKETPATH
+
 /* Define if we the user specifies an include file */
 #undef USER_INCLUDE
 
@@ -461,6 +470,9 @@
    byte first (like Motorola and SPARC, unlike Intel and VAX).  */
 #undef WORDS_BIGENDIAN
 
+/* Define if you have TCP wrappers support */
+#undef TCPWRAPPERS
+
 /* Define if lex declares yytext as a char * by default, not a char[].  */
 #undef YYTEXT_POINTER
 
